# Python 115 FTP Server.

## 安装

你可以通过 [pypi](https://pypi.org/project/p115ftp/) 安装

```console
pip install -U p115ftp
```

## 用法

### 模块

```python
from p115ftp import P115FS

P115FS.run_forever()
```

### 命令行

```console
$ p115ftp -h

```
